#!/usr/bin/env python
import json
import optparse
import sys
from check import error, output


# Crontab configuration plugin (maintenance)
# ==========================================
#
# Checks crontab installation of Magento cron
#
# Command line arguments
# ----------------------
# --magentopath    [required] Path to magento root
#
# Output
# ------
# Output
# - crontab
#
# The plugin returns:
# - string state       State of the crontab configuration. One of:
#                        - "none":   No cron.php installed in crontab
#                        - "custom": Cron.php is installed in crontab
#                        - "auto":   Cron.php is installed in crontab by us
#
# Interpreting
# ------------
# Cron should always be configured, so "none" is not good

def main(magentopath):
    if not magentopath:
        error("No Magento path given. User --magentopath=xx")

    try:
        from byte_rpc.commands.cronmanager import detect_cron
    except ImportError:
        error("cronmanager is not available")

    try:
        state = detect_cron(magentopath)
    except RuntimeError as e:
        error("detect_cron failed: '%s'" % e)

    output({
        'crontab': {
            'state': state
        }
    })


def stub():
    output({
        'crontab': {
            'state': 'auto'
        }
    })


if __name__ == '__main__':
    parser = optparse.OptionParser()
    parser.add_option('--magentopath', action="store", type="string", dest="magentopath")
    parser.add_option('--stub', action="store_true", dest="stub")
    options, args = parser.parse_args()

    if options.stub:
        stub()
    else:
        main(options.magentopath)
