#!/usr/bin/php -d opcache.enable_cli=0
<?php

require_once 'Abstract.php';

/**
 * Dangerous files plugin (security)
 * =================================
 *
 * Returns information about potential dangerous files, like public readable backup files.
 *
 * Command line arguments
 * ----------------------
 * --magentopath    [required] Path to magento root
 *
 * Output
 * ------
 * Output key(s)
 * - dangerous_files
 *
 * It returns an array of file names in the document root which have suspicious names, like
 * `*.sql`, `*.tgz` and `*.zip`.
 *
 * Interpreting
 * ------------
 * Every file in this array is worth noticing, as it's a potential security problem.
 */
class Byte_Mavo_Plugin_DangerousFiles extends Byte_Mavo_Plugin_Abstract
{
    protected $_stub = '{"dangerous_files":["\/backup.sql","\/dump.sql","\/sandbox.tgz"]}';


    public function run()
    {
        parent::run();

        $this->addResult('dangerous_files', $this->getDangerousFiles());
        $this->outputResult();
    }


    public function getDangerousFiles()
    {
        $checks = array(
            'sql' => '*.sql',
            'gz'  => '*.gz',
            'tgz' => '*.tgz',
            'zip' => '*.zip',
        );

        $result = array();
        $magentoBasePath = $this->checkMagentoPathArgument();
        $offset = strlen($magentoBasePath);
        foreach ($checks as $name => $pattern) {
            if ($files = glob($magentoBasePath . '/' . $pattern)) {
                foreach ($files as $key => $file) {
                    if (substr($file, 0, $offset) == $magentoBasePath) {
                        $file = substr($file, $offset);
                    }
                    $result[] = $file;
                }
            }
        }

        return $result;
    }

}

try {
    $plugin = new Byte_Mavo_Plugin_DangerousFiles();
    $plugin->run();
} catch (Exception $e) {
    Byte_Mavo_Plugin_DangerousFiles::dieError('Error running plugin: ' . $e->getMessage());
}
