#!/usr/bin/php -d opcache.enable_cli=0
<?php

require_once 'Abstract.php';

/**
 * Extensions plugin (informational)
 * =================================
 *
 * Returns information about installed extensions.
 *
 * Command line arguments
 * ----------------------
 * --magentopath    [required] Path to magento root
 *
 * Output
 * ------
 * Output key(s)
 * - extensions
 *
 * It returns an array of extensions, being objects with the following keys:
 * - string name
 * - bool   active
 * - string version  Version cannot be determined if the extension is inactive and will be returned as an empty string
 *
 * Interpreting
 * ------------
 * There is no good or bad here.
 */
class Byte_Mavo_Plugin_Extensions extends Byte_Mavo_Plugin_Abstract
{
    // this is the output of Magento demo data
    protected $_stub = '{"extensions":[{"name":"Mage_Core","active":true,"version":"1.6.0.2"},{"name":"Mage_Eav","active":true,"version":"1.6.0.0"},{"name":"Mage_Page","active":true,"version":"1.6.0.0"},{"name":"Mage_Install","active":true,"version":"0.7.0"}]}';


    public function run()
    {
        parent::run();

        $this->addResult('extensions', $this->getExtensions());
        $this->outputResult();
    }


    public function getExtensions()
    {
        $this->createMagentoEnvironment();

        $modules = array();
        foreach (Mage::getConfig()->getNode('modules')->children() as $moduleName => $moduleNode) {
            $modules[] = array(
                'name' => $moduleName,
                'active' => 'true' === (string)$moduleNode->active ? true : false,
                'version' => (string)$moduleNode->version,
            );
        }

        return $modules;
    }

}

try {
    $plugin = new Byte_Mavo_Plugin_Extensions();
    $plugin->run();
} catch (Exception $e) {
    Byte_Mavo_Plugin_Extensions::dieError('Error running plugin: ' . $e->getMessage());
}
