#!/usr/bin/php -d opcache.enable_cli=0
<?php

require_once 'Abstract.php';

/**
 * Redis plugin check
 * =======================================
 *
 * Checks whether a Magento has Cm's redis cache module installed
 *
 * See:
 * https://github.com/colinmollenhour/Cm_Cache_Backend_Redis
 *
 * Command line arguments
 * ----------------------
 * --magentopath  [required] Path to magento root
 *
 * Output
 * ------
 * Output key(s)
 * - redis_module_installed
 *
 * Returns object with keys:
 * - bool    result      Is the module installed?
 *
 */
class Byte_Mavo_Plugin_CheckRedisPlugin extends Byte_Mavo_Plugin_Abstract
{
    protected $_stub = '{"redis_module_installed":{"result":true}}';

    public function run()
    {
        parent::run();

        $this->addResult('redis_module_installed', $this->getRedisModuleInstalled());
        $this->outputResult();
    }

    public function getRedisModuleInstalled()
    {
        $this->checkMagentoPathArgument();
        require_once $this->_magentoPath . '/app/Mage.php';

        $requiredClasses = array(
            'Cm_Cache_Backend_Redis',
            'Credis_Client',
        );

        $result = true;
        foreach ($requiredClasses as $class) {
            $result = $result && @class_exists($class);
        }
        
        return array('result' => $result);
    }

}

try {
    $plugin = new Byte_Mavo_Plugin_CheckRedisPlugin();
    $plugin->run();
} catch (Exception $e) {
    Byte_Mavo_Plugin_CheckRedisPlugin::dieError('Error running plugin: ' . $e->getMessage());
}
