#!/usr/bin/php -d opcache.enable_cli=0
<?php

require_once 'Abstract.php';

/**
 * Stores plugin
 * =============================
 *
 * Lists all stores and base urls.
 *
 * Command line arguments
 * ----------------------
 * --magentopath    [required] Path to magento root
 *
 * Output
 * ------
 * Output key(s)
 * - stores
 *
 * Returns an array with stores. Each store is an object with keys:
 * - int   id
 * - str   code
 * - str   name
 * - str   unsecure_baseurl
 * - str   secure_baseurl
 *
 * Interpreting
 * ------------
 * -
 */
class Byte_Mavo_Plugin_Stores extends Byte_Mavo_Plugin_Abstract
{
    protected $_stubs = array(
        '{"stores":{"1":{"id":"1","code":"default","name":"default","unsecure_base_url":"http:\/\/10.0.3.135\/","secure_base_url":"http:\/\/10.0.3.135\/"}}}',
        '{"stores":{"1":{"id":"1","code":"default","name":"default","unsecure_base_url":"http:\/\/www.kookshopdepepermolen.nl\/","secure_base_url":"https:\/\/www.kookshopdepepermolen.nl\/"},"3":{"id":"3","code":"kookshoppepermolen","name":"Kookshop-Pepermolen","unsecure_base_url":"http:\/\/www.kookshopdepepermolen.nl\/","secure_base_url":"https:\/\/www.kookshopdepepermolen.nl\/"},"4":{"id":"4","code":"kitchenvitrinefr","name":"Kitchenvitrine-fr","unsecure_base_url":"http:\/\/www.kitchenvitrine.fr\/","secure_base_url":"https:\/\/www.kitchenvitrine.fr\/"}}}',
        '{"error": "Magento not found"}',
    );

    public function run()
    {
        parent::run();

        $this->addResult('stores', $this->getStores());
        $this->outputResult();
    }


    public function getStores()
    {
        $this->createMagentoEnvironment();

        # Inspired by https://github.com/netz98/n98-magerun/blob/f56de425471fca3aa636776c8d35821aa1c66eea/src/N98/Magento/Command/System/Store/Config/BaseUrlListCommand.php#L41
        foreach (\Mage::app()->getStores() as $store) {
            $result[$store->getId()] = array(
                'id' => $store->getId(),
                'code' => $store->getCode(),
                'name' => $store->getName(),
                'unsecure_base_url' => \Mage::getStoreConfig('web/unsecure/base_url', $store),
                'secure_base_url' => \Mage::getStoreConfig('web/secure/base_url', $store),
            );
        }
        ksort($result);
        return $result;
    }

}

try {
    $plugin = new Byte_Mavo_Plugin_Stores();
    $plugin->run();
} catch (Exception $e) {
    Byte_Mavo_Plugin_Stores::dieError('Error running plugin: ' . $e->getMessage());
}
