#!/usr/bin/php -d opcache.enable_cli=0
<?php

require_once 'Abstract.php';

/**
 * Zend XMLRPC Bug check plugin (security)
 * =======================================
 *
 * Checks whether a Magento installation is still vulnerable to the
 * 'Zend XMLRPC Bug'
 *
 * See:
 * http://www.magentocommerce.com/blog/comments/important-security-update-zend-platform-vulnerability
 *
 * Command line arguments
 * ----------------------
 * --magentopath  [required] Path to magento root
 *
 * Output
 * ------
 * Output key(s)
 * - zendxmlrpc
 *
 * Returns object with keys:
 * - bool    vulnerable  Is the Magento installation vulnerable?
 * - string  file        The file it checked (could be in app/code/local for instance)
 *
 * Interpreting
 * ------------
 * Worth noticing (alarming):
 * - vulnerable == true
 */
class Byte_Mavo_Plugin_CheckZendXmlRpc extends Byte_Mavo_Plugin_Abstract
{
    protected $_stub = '{"vulnerable":{"result":true}}';

    public function run()
    {
        parent::run();

        $this->addResult('zendxmlrpc', $this->getZendXmlRpcVulnerable());
        $this->outputResult();
    }

    public function getZendXmlRpcVulnerable()
    {
        $this->_setMagentoIncludePath();
        if ($filePath = stream_resolve_include_path('Zend/XmlRpc/Request.php')) {
            $fileContents = file_get_contents('Zend/XmlRpc/Request.php', true);
            if (preg_match('/libxml_disable_entity_loader/i', $fileContents)) {
                return array('vulnerable' => false, 'file' => $filePath);
            }
            return array('vulnerable' => true, 'file' => $filePath);
        }

        $this->dieError('Cannot find Zend/XmlRpc/Request.php to check vulnerability');
    }

}

try {
    $plugin = new Byte_Mavo_Plugin_CheckZendXmlRpc();
    $plugin->run();
} catch (Exception $e) {
    Byte_Mavo_Plugin_CheckZendXmlRpc::dieError('Error running plugin: ' . $e->getMessage());
}
